pub enum Either<L, R> {
Left(L),
Right(R),
}Expand description
The enum Either with variants Left and Right is a general purpose
sum type with two cases.
The Either type is symmetric and treats its variants the same way, without
preference.
(For representing success or error, use the regular Result enum instead.)
Variants
Implementations
Sourceimpl<L, R> Either<L, R>
impl<L, R> Either<L, R>
Sourcepub fn is_left(&self) -> bool
Available on crate feature std only.
pub fn is_left(&self) -> bool
std only.Return true if the value is the Left variant.
use either::*;
let values = [Left(1), Right("the right value")];
assert_eq!(values[0].is_left(), true);
assert_eq!(values[1].is_left(), false);Sourcepub fn is_right(&self) -> bool
Available on crate feature std only.
pub fn is_right(&self) -> bool
std only.Return true if the value is the Right variant.
use either::*;
let values = [Left(1), Right("the right value")];
assert_eq!(values[0].is_right(), false);
assert_eq!(values[1].is_right(), true);Sourcepub fn left(self) -> Option<L>
Available on crate feature std only.
pub fn left(self) -> Option<L>
std only.Convert the left side of Either<L, R> to an Option<L>.
use either::*;
let left: Either<_, ()> = Left("some value");
assert_eq!(left.left(), Some("some value"));
let right: Either<(), _> = Right(321);
assert_eq!(right.left(), None);Sourcepub fn right(self) -> Option<R>
Available on crate feature std only.
pub fn right(self) -> Option<R>
std only.Convert the right side of Either<L, R> to an Option<R>.
use either::*;
let left: Either<_, ()> = Left("some value");
assert_eq!(left.right(), None);
let right: Either<(), _> = Right(321);
assert_eq!(right.right(), Some(321));Sourcepub fn as_ref(&self) -> Either<&L, &R> ⓘ
Available on crate feature std only.
pub fn as_ref(&self) -> Either<&L, &R> ⓘ
std only.Convert &Either<L, R> to Either<&L, &R>.
use either::*;
let left: Either<_, ()> = Left("some value");
assert_eq!(left.as_ref(), Left(&"some value"));
let right: Either<(), _> = Right("some value");
assert_eq!(right.as_ref(), Right(&"some value"));Sourcepub fn as_mut(&mut self) -> Either<&mut L, &mut R> ⓘ
Available on crate feature std only.
pub fn as_mut(&mut self) -> Either<&mut L, &mut R> ⓘ
std only.Convert &mut Either<L, R> to Either<&mut L, &mut R>.
use either::*;
fn mutate_left(value: &mut Either<u32, u32>) {
if let Some(l) = value.as_mut().left() {
*l = 999;
}
}
let mut left = Left(123);
let mut right = Right(123);
mutate_left(&mut left);
mutate_left(&mut right);
assert_eq!(left, Left(999));
assert_eq!(right, Right(123));Sourcepub fn as_pin_ref(self: Pin<&Either<L, R>>) -> Either<Pin<&L>, Pin<&R>> ⓘ
Available on crate feature std only.
pub fn as_pin_ref(self: Pin<&Either<L, R>>) -> Either<Pin<&L>, Pin<&R>> ⓘ
std only.Convert Pin<&Either<L, R>> to Either<Pin<&L>, Pin<&R>>,
pinned projections of the inner variants.
Sourcepub fn as_pin_mut(
self: Pin<&mut Either<L, R>>,
) -> Either<Pin<&mut L>, Pin<&mut R>> ⓘ
Available on crate feature std only.
pub fn as_pin_mut( self: Pin<&mut Either<L, R>>, ) -> Either<Pin<&mut L>, Pin<&mut R>> ⓘ
std only.Convert Pin<&mut Either<L, R>> to Either<Pin<&mut L>, Pin<&mut R>>,
pinned projections of the inner variants.
Sourcepub fn flip(self) -> Either<R, L> ⓘ
Available on crate feature std only.
pub fn flip(self) -> Either<R, L> ⓘ
std only.Convert Either<L, R> to Either<R, L>.
use either::*;
let left: Either<_, ()> = Left(123);
assert_eq!(left.flip(), Right(123));
let right: Either<(), _> = Right("some value");
assert_eq!(right.flip(), Left("some value"));Sourcepub fn map_left<F, M>(self, f: F) -> Either<M, R> ⓘwhere
F: FnOnce(L) -> M,
Available on crate feature std only.
pub fn map_left<F, M>(self, f: F) -> Either<M, R> ⓘwhere
F: FnOnce(L) -> M,
std only.Apply the function f on the value in the Left variant if it is present rewrapping the
result in Left.
use either::*;
let left: Either<_, u32> = Left(123);
assert_eq!(left.map_left(|x| x * 2), Left(246));
let right: Either<u32, _> = Right(123);
assert_eq!(right.map_left(|x| x * 2), Right(123));Sourcepub fn map_right<F, S>(self, f: F) -> Either<L, S> ⓘwhere
F: FnOnce(R) -> S,
Available on crate feature std only.
pub fn map_right<F, S>(self, f: F) -> Either<L, S> ⓘwhere
F: FnOnce(R) -> S,
std only.Apply the function f on the value in the Right variant if it is present rewrapping the
result in Right.
use either::*;
let left: Either<_, u32> = Left(123);
assert_eq!(left.map_right(|x| x * 2), Left(123));
let right: Either<u32, _> = Right(123);
assert_eq!(right.map_right(|x| x * 2), Right(246));Sourcepub fn map_either<F, G, M, S>(self, f: F, g: G) -> Either<M, S> ⓘ
Available on crate feature std only.
pub fn map_either<F, G, M, S>(self, f: F, g: G) -> Either<M, S> ⓘ
std only.Apply the functions f and g to the Left and Right variants
respectively. This is equivalent to
bimap
in functional programming.
use either::*;
let f = |s: String| s.len();
let g = |u: u8| u.to_string();
let left: Either<String, u8> = Left("loopy".into());
assert_eq!(left.map_either(f, g), Left(5));
let right: Either<String, u8> = Right(42);
assert_eq!(right.map_either(f, g), Right("42".into()));Sourcepub fn map_either_with<Ctx, F, G, M, S>(
self,
ctx: Ctx,
f: F,
g: G,
) -> Either<M, S> ⓘ
Available on crate feature std only.
pub fn map_either_with<Ctx, F, G, M, S>( self, ctx: Ctx, f: F, g: G, ) -> Either<M, S> ⓘ
std only.Similar to map_either, with an added context ctx accessible to
both functions.
use either::*;
let mut sum = 0;
// Both closures want to update the same value, so pass it as context.
let mut f = |sum: &mut usize, s: String| { *sum += s.len(); s.to_uppercase() };
let mut g = |sum: &mut usize, u: usize| { *sum += u; u.to_string() };
let left: Either<String, usize> = Left("loopy".into());
assert_eq!(left.map_either_with(&mut sum, &mut f, &mut g), Left("LOOPY".into()));
let right: Either<String, usize> = Right(42);
assert_eq!(right.map_either_with(&mut sum, &mut f, &mut g), Right("42".into()));
assert_eq!(sum, 47);Sourcepub fn either<F, G, T>(self, f: F, g: G) -> T
Available on crate feature std only.
pub fn either<F, G, T>(self, f: F, g: G) -> T
std only.Apply one of two functions depending on contents, unifying their result. If the value is
Left(L) then the first function f is applied; if it is Right(R) then the second
function g is applied.
use either::*;
fn square(n: u32) -> i32 { (n * n) as i32 }
fn negate(n: i32) -> i32 { -n }
let left: Either<u32, i32> = Left(4);
assert_eq!(left.either(square, negate), 16);
let right: Either<u32, i32> = Right(-4);
assert_eq!(right.either(square, negate), 4);Sourcepub fn either_with<Ctx, F, G, T>(self, ctx: Ctx, f: F, g: G) -> T
Available on crate feature std only.
pub fn either_with<Ctx, F, G, T>(self, ctx: Ctx, f: F, g: G) -> T
std only.Like either, but provide some context to whichever of the
functions ends up being called.
// In this example, the context is a mutable reference
use either::*;
let mut result = Vec::new();
let values = vec![Left(2), Right(2.7)];
for value in values {
value.either_with(&mut result,
|ctx, integer| ctx.push(integer),
|ctx, real| ctx.push(f64::round(real) as i32));
}
assert_eq!(result, vec![2, 3]);Sourcepub fn left_and_then<F, S>(self, f: F) -> Either<S, R> ⓘ
Available on crate feature std only.
pub fn left_and_then<F, S>(self, f: F) -> Either<S, R> ⓘ
std only.Apply the function f on the value in the Left variant if it is present.
use either::*;
let left: Either<_, u32> = Left(123);
assert_eq!(left.left_and_then::<_,()>(|x| Right(x * 2)), Right(246));
let right: Either<u32, _> = Right(123);
assert_eq!(right.left_and_then(|x| Right::<(), _>(x * 2)), Right(123));Sourcepub fn right_and_then<F, S>(self, f: F) -> Either<L, S> ⓘ
Available on crate feature std only.
pub fn right_and_then<F, S>(self, f: F) -> Either<L, S> ⓘ
std only.Apply the function f on the value in the Right variant if it is present.
use either::*;
let left: Either<_, u32> = Left(123);
assert_eq!(left.right_and_then(|x| Right(x * 2)), Left(123));
let right: Either<u32, _> = Right(123);
assert_eq!(right.right_and_then(|x| Right(x * 2)), Right(246));Sourcepub fn into_iter(
self,
) -> Either<<L as IntoIterator>::IntoIter, <R as IntoIterator>::IntoIter> ⓘ
Available on crate feature std only.
pub fn into_iter( self, ) -> Either<<L as IntoIterator>::IntoIter, <R as IntoIterator>::IntoIter> ⓘ
std only.Convert the inner value to an iterator.
This requires the Left and Right iterators to have the same item type.
See factor_into_iter to iterate different types.
use either::*;
let left: Either<_, Vec<u32>> = Left(vec![1, 2, 3, 4, 5]);
let mut right: Either<Vec<u32>, _> = Right(vec![]);
right.extend(left.into_iter());
assert_eq!(right, Right(vec![1, 2, 3, 4, 5]));Sourcepub fn iter(
&self,
) -> Either<<&L as IntoIterator>::IntoIter, <&R as IntoIterator>::IntoIter> ⓘwhere
&'a L: for<'a> IntoIterator,
&'a R: for<'a> IntoIterator<Item = <&'a L as IntoIterator>::Item>,
Available on crate feature std only.
pub fn iter(
&self,
) -> Either<<&L as IntoIterator>::IntoIter, <&R as IntoIterator>::IntoIter> ⓘwhere
&'a L: for<'a> IntoIterator,
&'a R: for<'a> IntoIterator<Item = <&'a L as IntoIterator>::Item>,
std only.Borrow the inner value as an iterator.
This requires the Left and Right iterators to have the same item type.
See factor_iter to iterate different types.
use either::*;
let left: Either<_, &[u32]> = Left(vec![2, 3]);
let mut right: Either<Vec<u32>, _> = Right(&[4, 5][..]);
let mut all = vec![1];
all.extend(left.iter());
all.extend(right.iter());
assert_eq!(all, vec![1, 2, 3, 4, 5]);Sourcepub fn iter_mut(
&mut self,
) -> Either<<&mut L as IntoIterator>::IntoIter, <&mut R as IntoIterator>::IntoIter> ⓘwhere
&'a mut L: for<'a> IntoIterator,
&'a mut R: for<'a> IntoIterator<Item = <&'a mut L as IntoIterator>::Item>,
Available on crate feature std only.
pub fn iter_mut(
&mut self,
) -> Either<<&mut L as IntoIterator>::IntoIter, <&mut R as IntoIterator>::IntoIter> ⓘwhere
&'a mut L: for<'a> IntoIterator,
&'a mut R: for<'a> IntoIterator<Item = <&'a mut L as IntoIterator>::Item>,
std only.Mutably borrow the inner value as an iterator.
This requires the Left and Right iterators to have the same item type.
See factor_iter_mut to iterate different types.
use either::*;
let mut left: Either<_, &mut [u32]> = Left(vec![2, 3]);
for l in left.iter_mut() {
*l *= *l
}
assert_eq!(left, Left(vec![4, 9]));
let mut inner = [4, 5];
let mut right: Either<Vec<u32>, _> = Right(&mut inner[..]);
for r in right.iter_mut() {
*r *= *r
}
assert_eq!(inner, [16, 25]);Sourcepub fn factor_into_iter(
self,
) -> IterEither<<L as IntoIterator>::IntoIter, <R as IntoIterator>::IntoIter>where
L: IntoIterator,
R: IntoIterator,
Available on crate feature std only.
pub fn factor_into_iter(
self,
) -> IterEither<<L as IntoIterator>::IntoIter, <R as IntoIterator>::IntoIter>where
L: IntoIterator,
R: IntoIterator,
std only.Converts an Either of Iterators to be an Iterator of Eithers
Unlike into_iter, this does not require the
Left and Right iterators to have the same item type.
use either::*;
let left: Either<_, Vec<u8>> = Left(&["hello"]);
assert_eq!(left.factor_into_iter().next(), Some(Left(&"hello")));
let right: Either<&[&str], _> = Right(vec![0, 1]);
assert_eq!(right.factor_into_iter().collect::<Vec<_>>(), vec![Right(0), Right(1)]);
Sourcepub fn factor_iter(
&self,
) -> IterEither<<&L as IntoIterator>::IntoIter, <&R as IntoIterator>::IntoIter>
Available on crate feature std only.
pub fn factor_iter( &self, ) -> IterEither<<&L as IntoIterator>::IntoIter, <&R as IntoIterator>::IntoIter>
std only.Borrows an Either of Iterators to be an Iterator of Eithers
Unlike iter, this does not require the
Left and Right iterators to have the same item type.
use either::*;
let left: Either<_, Vec<u8>> = Left(["hello"]);
assert_eq!(left.factor_iter().next(), Some(Left(&"hello")));
let right: Either<[&str; 2], _> = Right(vec![0, 1]);
assert_eq!(right.factor_iter().collect::<Vec<_>>(), vec![Right(&0), Right(&1)]);
Sourcepub fn factor_iter_mut(
&mut self,
) -> IterEither<<&mut L as IntoIterator>::IntoIter, <&mut R as IntoIterator>::IntoIter>
Available on crate feature std only.
pub fn factor_iter_mut( &mut self, ) -> IterEither<<&mut L as IntoIterator>::IntoIter, <&mut R as IntoIterator>::IntoIter>
std only.Mutably borrows an Either of Iterators to be an Iterator of Eithers
Unlike iter_mut, this does not require the
Left and Right iterators to have the same item type.
use either::*;
let mut left: Either<_, Vec<u8>> = Left(["hello"]);
left.factor_iter_mut().for_each(|x| *x.unwrap_left() = "goodbye");
assert_eq!(left, Left(["goodbye"]));
let mut right: Either<[&str; 2], _> = Right(vec![0, 1, 2]);
right.factor_iter_mut().for_each(|x| if let Right(r) = x { *r = -*r; });
assert_eq!(right, Right(vec![0, -1, -2]));
Sourcepub fn left_or(self, other: L) -> L
Available on crate feature std only.
pub fn left_or(self, other: L) -> L
std only.Return left value or given value
Arguments passed to left_or are eagerly evaluated; if you are passing
the result of a function call, it is recommended to use
left_or_else, which is lazily evaluated.
Examples
let left: Either<&str, &str> = Left("left");
assert_eq!(left.left_or("foo"), "left");
let right: Either<&str, &str> = Right("right");
assert_eq!(right.left_or("left"), "left");Sourcepub fn left_or_default(self) -> Lwhere
L: Default,
Available on crate feature std only.
pub fn left_or_default(self) -> Lwhere
L: Default,
std only.Return left or a default
Examples
let left: Either<String, u32> = Left("left".to_string());
assert_eq!(left.left_or_default(), "left");
let right: Either<String, u32> = Right(42);
assert_eq!(right.left_or_default(), String::default());Sourcepub fn left_or_else<F>(self, f: F) -> Lwhere
F: FnOnce(R) -> L,
Available on crate feature std only.
pub fn left_or_else<F>(self, f: F) -> Lwhere
F: FnOnce(R) -> L,
std only.Returns left value or computes it from a closure
Examples
let left: Either<String, u32> = Left("3".to_string());
assert_eq!(left.left_or_else(|_| unreachable!()), "3");
let right: Either<String, u32> = Right(3);
assert_eq!(right.left_or_else(|x| x.to_string()), "3");Sourcepub fn right_or(self, other: R) -> R
Available on crate feature std only.
pub fn right_or(self, other: R) -> R
std only.Return right value or given value
Arguments passed to right_or are eagerly evaluated; if you are passing
the result of a function call, it is recommended to use
right_or_else, which is lazily evaluated.
Examples
let right: Either<&str, &str> = Right("right");
assert_eq!(right.right_or("foo"), "right");
let left: Either<&str, &str> = Left("left");
assert_eq!(left.right_or("right"), "right");Sourcepub fn right_or_default(self) -> Rwhere
R: Default,
Available on crate feature std only.
pub fn right_or_default(self) -> Rwhere
R: Default,
std only.Return right or a default
Examples
let left: Either<String, u32> = Left("left".to_string());
assert_eq!(left.right_or_default(), u32::default());
let right: Either<String, u32> = Right(42);
assert_eq!(right.right_or_default(), 42);Sourcepub fn right_or_else<F>(self, f: F) -> Rwhere
F: FnOnce(L) -> R,
Available on crate feature std only.
pub fn right_or_else<F>(self, f: F) -> Rwhere
F: FnOnce(L) -> R,
std only.Returns right value or computes it from a closure
Examples
let left: Either<String, u32> = Left("3".to_string());
assert_eq!(left.right_or_else(|x| x.parse().unwrap()), 3);
let right: Either<String, u32> = Right(3);
assert_eq!(right.right_or_else(|_| unreachable!()), 3);Sourcepub fn unwrap_left(self) -> Lwhere
R: Debug,
Available on crate feature std only.
pub fn unwrap_left(self) -> Lwhere
R: Debug,
std only.Sourcepub fn unwrap_right(self) -> Rwhere
L: Debug,
Available on crate feature std only.
pub fn unwrap_right(self) -> Rwhere
L: Debug,
std only.Sourcepub fn expect_left(self, msg: &str) -> Lwhere
R: Debug,
Available on crate feature std only.
pub fn expect_left(self, msg: &str) -> Lwhere
R: Debug,
std only.Sourcepub fn expect_right(self, msg: &str) -> Rwhere
L: Debug,
Available on crate feature std only.
pub fn expect_right(self, msg: &str) -> Rwhere
L: Debug,
std only.Sourcepub fn either_into<T>(self) -> T
Available on crate feature std only.
pub fn either_into<T>(self) -> T
std only.Convert the contained value into T
Examples
// Both u16 and u32 can be converted to u64.
let left: Either<u16, u32> = Left(3u16);
assert_eq!(left.either_into::<u64>(), 3u64);
let right: Either<u16, u32> = Right(7u32);
assert_eq!(right.either_into::<u64>(), 7u64);Sourceimpl<L, R> Either<Option<L>, Option<R>>
impl<L, R> Either<Option<L>, Option<R>>
Sourcepub fn factor_none(self) -> Option<Either<L, R>>
Available on crate feature std only.
pub fn factor_none(self) -> Option<Either<L, R>>
std only.Factors out None from an Either of Option.
use either::*;
let left: Either<_, Option<String>> = Left(Some(vec![0]));
assert_eq!(left.factor_none(), Some(Left(vec![0])));
let right: Either<Option<Vec<u8>>, _> = Right(Some(String::new()));
assert_eq!(right.factor_none(), Some(Right(String::new())));Sourceimpl<L, R, E> Either<Result<L, E>, Result<R, E>>
impl<L, R, E> Either<Result<L, E>, Result<R, E>>
Sourcepub fn factor_err(self) -> Result<Either<L, R>, E>
Available on crate feature std only.
pub fn factor_err(self) -> Result<Either<L, R>, E>
std only.Factors out a homogenous type from an Either of Result.
Here, the homogeneous type is the Err type of the Result.
use either::*;
let left: Either<_, Result<String, u32>> = Left(Ok(vec![0]));
assert_eq!(left.factor_err(), Ok(Left(vec![0])));
let right: Either<Result<Vec<u8>, u32>, _> = Right(Ok(String::new()));
assert_eq!(right.factor_err(), Ok(Right(String::new())));Sourceimpl<T, L, R> Either<Result<T, L>, Result<T, R>>
impl<T, L, R> Either<Result<T, L>, Result<T, R>>
Sourcepub fn factor_ok(self) -> Result<T, Either<L, R>>
Available on crate feature std only.
pub fn factor_ok(self) -> Result<T, Either<L, R>>
std only.Factors out a homogenous type from an Either of Result.
Here, the homogeneous type is the Ok type of the Result.
use either::*;
let left: Either<_, Result<u32, String>> = Left(Err(vec![0]));
assert_eq!(left.factor_ok(), Err(Left(vec![0])));
let right: Either<Result<u32, Vec<u8>>, _> = Right(Err(String::new()));
assert_eq!(right.factor_ok(), Err(Right(String::new())));Sourceimpl<T, L, R> Either<(T, L), (T, R)>
impl<T, L, R> Either<(T, L), (T, R)>
Sourcepub fn factor_first(self) -> (T, Either<L, R>)
Available on crate feature std only.
pub fn factor_first(self) -> (T, Either<L, R>)
std only.Factor out a homogeneous type from an either of pairs.
Here, the homogeneous type is the first element of the pairs.
use either::*;
let left: Either<_, (u32, String)> = Left((123, vec![0]));
assert_eq!(left.factor_first().0, 123);
let right: Either<(u32, Vec<u8>), _> = Right((123, String::new()));
assert_eq!(right.factor_first().0, 123);Sourceimpl<T, L, R> Either<(L, T), (R, T)>
impl<T, L, R> Either<(L, T), (R, T)>
Sourcepub fn factor_second(self) -> (Either<L, R>, T)
Available on crate feature std only.
pub fn factor_second(self) -> (Either<L, R>, T)
std only.Factor out a homogeneous type from an either of pairs.
Here, the homogeneous type is the second element of the pairs.
use either::*;
let left: Either<_, (String, u32)> = Left((vec![0], 123));
assert_eq!(left.factor_second().1, 123);
let right: Either<(Vec<u8>, u32), _> = Right((String::new(), 123));
assert_eq!(right.factor_second().1, 123);Sourceimpl<T> Either<T, T>
impl<T> Either<T, T>
Sourcepub fn into_inner(self) -> T
Available on crate feature std only.
pub fn into_inner(self) -> T
std only.Extract the value of an either over two equivalent types.
use either::*;
let left: Either<_, u32> = Left(123);
assert_eq!(left.into_inner(), 123);
let right: Either<u32, _> = Right(123);
assert_eq!(right.into_inner(), 123);Sourcepub fn map<F, M>(self, f: F) -> Either<M, M> ⓘwhere
F: FnOnce(T) -> M,
Available on crate feature std only.
pub fn map<F, M>(self, f: F) -> Either<M, M> ⓘwhere
F: FnOnce(T) -> M,
std only.Map f over the contained value and return the result in the
corresponding variant.
use either::*;
let value: Either<_, i32> = Right(42);
let other = value.map(|x| x * 2);
assert_eq!(other, Right(84));Sourceimpl<L, R> Either<&L, &R>
impl<L, R> Either<&L, &R>