pub fn from_fn<F, Item, Meta, CanEnd>(func: F) -> FromFn<F, Item, Meta, CanEnd>Expand description
Creates a synchronous pull from a closure.
The closure is called each time the pull is polled and should return a PullStep.
pub fn from_fn<F, Item, Meta, CanEnd>(func: F) -> FromFn<F, Item, Meta, CanEnd>Creates a synchronous pull from a closure.
The closure is called each time the pull is polled and should return a PullStep.