iter

Function iter 

pub fn iter<I: IntoIterator>(iter: I) -> Iter<I::IntoIter>
Creates a pull from an iterator.

This is the primary way to create a pull from synchronous data. The resulting pull will never pend and will end when the iterator is exhausted.