pub const fn stream_compat<Pul: Pull>(pull: Pul) -> StreamCompat<Pul>Expand description
Creates a StreamCompat adapter that wraps a Pull and implements futures_core::stream::Stream.
pub const fn stream_compat<Pul: Pull>(pull: Pul) -> StreamCompat<Pul>Creates a StreamCompat adapter that wraps a Pull and implements futures_core::stream::Stream.