pub const fn stream_ready<S>(stream: S, waker: Waker) -> StreamReady<S>where
S: Stream,Expand description
Creates a pull from a futures::Stream with a custom waker.
This variant uses a provided waker function instead of requiring a context.
When the stream returns Pending, this pull treats it as ended (non-blocking).