Next

Struct Next 

pub struct Next<Prev> { /* private fields */ }
A future which resolves with the next item from a Pull.

This is the Pull equivalent of the StreamExt::next() future. It polls the underlying pull and returns the result as a future.