StreamCompat

Struct StreamCompat 

pub struct StreamCompat<Pul> { /* private fields */ }
Adapter that wraps a Pull to implement the Stream trait.

Implementations

Source

impl<Pul> StreamCompat<Pul>

pub fn into_inner(self) -> Pul

Returns the wrapped Pull.

pub fn as_pin_mut(self: Pin<&mut Self>) -> Pin<&mut Pul>

Returns a pinned mutable reference to the wrapped Pull.

pub fn as_pin_ref(self: Pin<&Self>) -> Pin<&Pul>

Returns a pinned reference to the wrapped Pull.