DemuxVar

Struct DemuxVar 

pub struct DemuxVar<Pushes> { /* private fields */ }
Available on crate feature variadics only.
Push combinator that dispatches (usize, Item) pairs to one of several downstream pushes based on the index.

The downstream pushes are stored as a variadic tuple implementing PushVariadic. Each item (idx, value) is routed to the push at position idx in the variadic.

Context

The Push::Ctx for DemuxVar is the recursively merged context of all downstream pushes (via PushVariadic::Ctx), allowing each downstream push to have an independent context type.

Panics

Push::start_send panics if the index is out of bounds.