pub const fn flat_map_stream<Func, In, St, Meta, Next>(
func: Func,
next: Next,
) -> FlatMapStream<Next, Func, St, Meta>Expand description
Creates a FlatMapStream push that maps each item to a stream and flattens the results.
pub const fn flat_map_stream<Func, In, St, Meta, Next>(
func: Func,
next: Next,
) -> FlatMapStream<Next, Func, St, Meta>Creates a FlatMapStream push that maps each item to a stream and flattens the results.