SinkCompat

Struct SinkCompat 

pub struct SinkCompat<Psh> { /* private fields */ }
Adapter that wraps a Push to implement the Sink trait.

Implementations

Source

impl<Psh> SinkCompat<Psh>

pub fn into_inner(self) -> Psh

Returns the wrapped Push.

pub fn as_pin_mut(self: Pin<&mut Self>) -> Pin<&mut Psh>

Returns a pinned mutable reference to the wrapped Push.

pub fn as_pin_ref(self: Pin<&Self>) -> Pin<&Psh>

Returns a pinned reference to the wrapped Push.